.. include:: bibliography.txt

.. _studies:

Studies
=======

The following studies explore different aspects of the library, including its performance. This content is intended for an advanced audience.

.. toctree::
    :maxdepth: 1

    notebooks/binned_vs_unbinned
    notebooks/weighted_histograms
    notebooks/hesse_and_minos
    notebooks/numba
    notebooks/automatic_differentiation
    notebooks/cost_function_benchmarks
    notebooks/gof
    notebooks/template_gof
    notebooks/memory_layout
